@@ -20,8 +20,12 @@ commands = {
         'unregister': Command(unavailiable_in_context),
     },
     DiscordContext.DM_CHANNEL: {
-        'register': Command(register, "Text"),
-        'unregister': Command(unregister, "Text lmao"),
+        'register': Command(register,
+                            "Register your Minecraft player. Type password ONLY if you have a non-official account. DO "
+                            "NOT USE YOUR NORMAL PASSWORDS - THEY ARE TRANSMITTED IN PLAIN TEXT THROUGH DISCORD AND "
+                            "THROUGH THE INTERNET WHEN LOGGING IN THE MINECRAFT SERVER!"),
+        'unregister': Command(unregister,
+                              "Unregister your Minecraft player. Type the player name as a confirmation."),
     },
     DiscordContext.GROUP_CHANNEL: {
         'register': Command(unavailiable_in_context),
