@@ -76,15 +76,25 @@ class Mcdbot(discord.Client):
             nonlocal self, token
             try:
                 logger.info("Starting the main loop...")
+
                 try:
                     await self.redis.start()
+                except ConnectionError as ce:
+                    logger.error(f"Connection error => {ce}")
+
+                try:
                     await self.rcon.start()
+                except ConnectionError as ce:
+                    logger.error(f"Connection error => {ce}")
+
+                try:
                     await self.mojang_api.start()
                 except ConnectionError as ce:
                     logger.error(f"Connection error => {ce}")
+
                 await self.start(token)
             except Exception as e:
-                logger.exception("TEST", e)
+                logger.exception("Unhandled runner exception", e)
                 raise e
             finally:
                 logger.warning("Shutting down...")
