@@ -24,7 +24,7 @@ class Rcon(object):
             except Exception as e:
                 self.started = False
                 logger.exception("Failed to start the RCON driver!", e)
-                raise e
+                raise ConnectionError
             else:
                 self.started = True
 
