@@ -37,7 +37,7 @@ class Redis(object):
             except Exception as e:
                 self.started = False
                 logger.exception("Failed to start the Redis connector!", e)
-                raise e
+                raise ConnectionError
             else:
                 self.started = True
 
